Welcome to ESIBD Explorer’s documentation! — ESIBD Explorer 0.6 documentation

# Welcome to ESIBD Explorer’s documentation!

The ESIBD Explorer controls all aspects of an Electrospray Ion-Beam Deposition (ESIBD) experiment, including optimization and characterization of the ion-beam energy, beam intensity, and beam size, as well as monitoring of the deposition. At each step, results and metadata are saved to document the experiment and allow for later reproduction of all experimental conditions.

ESIBD Explorer was designed to be used intuitively and without the need to memorize a lengthy manual. The main functionality should be self-evident from the user interface (see tooltips!). However, there are some aspects worth discussing below in more detail to make sure you can make the most use of it. Please get in touch if you have any feature requests or bug reports. The ESIBD Explorer should allow researchers to focus on the science, instead of performing repetitive tasks manually.

ESIBD Explorer provides a plugin system and plugin templates that allow to add support for custom devices, scan modes, and more using only a few lines of code. It can therefore be used for a broad range of academic experiments beyond ESIBD. It does make it easy to generate a consistent user interface for your custom hardware and data, and takes care of saving and loading data and settings. It does not write device specific code for you, and it is recommended to create a standalone script for all required device communication before creating your custom plugin.

ESIBD Explorer is implemented based on Python and PyQt. It is optimized for Microsoft Windows 10 or higher and distributed under the GNU General Public License. There is no guarantee in case of any data loss due to malfunction of ESIBD Explorer. Users are responsible for backing up their own data and configuration files.

Contents:

- 1. Installation
  - 1.1. Standalone Windows installer
  - 1.2. From PyPi
  - 1.3. From source (Miniconda)
  - 1.4. From source (other)
- 2. Electrospray ion-beam deposition
- 3. User’s Guide
  - 3.1. Configuration and management
  - 3.2. Displays
  - 3.3. Live displays
  - 3.4. Device manager
  - 3.5. Console
  - 3.6. ESIBD specific plugins
- 4. Plugin development
  - 4.1. Plugin
  - 4.2. PluginManager
  - 4.3. Devices
  - 4.4. Channels
  - 4.5. Scan
  - 4.6. DeviceController
- 5. Library Reference
  - 5.1. The plugin module
  - 5.2. The core module
- 6. Acknowledgments
- 7. References

# Links

- Index

- Source code: https://github.com/ioneater/ESIBD-Explorer